Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(67)

Unified Diff: pkg/front_end/lib/src/fasta/scanner/array_based_scanner.dart

Issue 3002493002: generate synthetic and error tokens when missing digit (Closed)
Patch Set: rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/front_end/lib/src/fasta/scanner/array_based_scanner.dart
diff --git a/pkg/front_end/lib/src/fasta/scanner/array_based_scanner.dart b/pkg/front_end/lib/src/fasta/scanner/array_based_scanner.dart
index a5d7b09fe6e530e0e916e2975d237970694f92e8..4933378f113dd879b84d867a6b28840fed4c72e2 100644
--- a/pkg/front_end/lib/src/fasta/scanner/array_based_scanner.dart
+++ b/pkg/front_end/lib/src/fasta/scanner/array_based_scanner.dart
@@ -262,9 +262,9 @@ abstract class ArrayBasedScanner extends AbstractScanner {
@override
void appendSyntheticSubstringToken(
- TokenType type, int start, bool asciiOnly, String closingQuotes) {
+ TokenType type, int start, bool asciiOnly, String syntheticChars) {
appendToken(
- createSyntheticSubstringToken(type, start, asciiOnly, closingQuotes));
+ createSyntheticSubstringToken(type, start, asciiOnly, syntheticChars));
}
/**
@@ -282,13 +282,13 @@ abstract class ArrayBasedScanner extends AbstractScanner {
/**
* Returns a new synthetic substring from the scan offset [start]
* to the current [scanOffset] plus the [closingQuotes].
* The [closingQuotes] are appended to the unterminated string
* literal's lexeme but the returned token's length will *not* include
- * those closing quotes so as to be true to the original source.
+ * those additional characters so as to be true to the original source.
*/
analyzer.StringToken createSyntheticSubstringToken(
- TokenType type, int start, bool asciiOnly, String closingQuotes);
+ TokenType type, int start, bool asciiOnly, String syntheticChars);
/**
* This method is called to discard '<' from the "grouping" stack.
« no previous file with comments | « pkg/front_end/lib/src/fasta/scanner/abstract_scanner.dart ('k') | pkg/front_end/lib/src/fasta/scanner/string_scanner.dart » ('j') | no next file with comments »
@@ -282,13 +282,13 @@ abstract class ArrayBasedScanner extends AbstractScanner {
/**
* Returns a new synthetic substring from the scan offset [start]
- * to the current [scanOffset] plus the [closingQuotes].
- * The [closingQuotes] are appended to the unterminated string
+ * to the current [scanOffset] plus the [syntheticChars].
+ * The [syntheticChars] are appended to the unterminated string
* literal's lexeme but the returned token's length will *not* include

Powered by Google App Engine
This is Rietveld 408576698